@@ -5,7 +5,7 @@ test_that("Errors", {
 
   expect_error(
     arc_geo_categories("Food"),
-    "valid combination of x,y parameters or a valid bbox"
+    "valid combination of x,y arguments or a valid bbox"
   )
   expect_error(
     arc_geo_categories("Food", "a", "a"),
@@ -28,7 +28,6 @@ test_that("Messages", {
   skip_if_api_server()
   skip_if_offline()
 
-
   expect_message(
     out <- arc_geo_categories("POI", 200, 0),
     "longitudes have been restricted"
@@ -36,18 +35,19 @@ test_that("Messages", {
   expect_message(
     out <- arc_geo_categories(
       "Address,Postal,Coordinate System,POI",
-      0, 200
+      0,
+      200
     ),
     "latitudes have been restricted"
   )
 
-
   expect_snapshot(
     out <- arc_geo_categories("POI", x = -3.7242, y = 40.39094, verbose = TRUE)
   )
 
   expect_message(
-    out <- arc_geo_categories("POI",
+    out <- arc_geo_categories(
+      "POI",
       x = 3.7242,
       bbox = c(-3.8, 40.3, -3.65, 40.5)
     ),
@@ -55,7 +55,8 @@ test_that("Messages", {
   )
 
   expect_message(
-    out <- arc_geo_categories("POI",
+    out <- arc_geo_categories(
+      "POI",
       y = 3.7242,
       bbox = c(-3.8, 40.3, -3.65, 40.5)
     ),
@@ -68,52 +69,61 @@ test_that("Messages bbox", {
   skip_if_api_server()
   skip_if_offline()
 
-
-
   expect_snapshot(
-    out <- arc_geo_categories("POI",
-      x = -3.7242, y = 40.39094,
+    out <- arc_geo_categories(
+      "POI",
+      x = -3.7242,
+      y = 40.39094,
       bbox = "uno",
       verbose = TRUE
     )
   )
 
-
   expect_snapshot(
-    out <- arc_geo_categories("POI",
-      x = -3.7242, y = 40.39094,
+    out <- arc_geo_categories(
+      "POI",
+      x = -3.7242,
+      y = 40.39094,
       bbox = c("uno", NA),
       verbose = TRUE
     )
   )
 
   expect_snapshot(
-    out <- arc_geo_categories("POI",
-      x = -3.7242, y = 40.39094,
+    out <- arc_geo_categories(
+      "POI",
+      x = -3.7242,
+      y = 40.39094,
       bbox = LETTERS[1:4],
       verbose = TRUE
     )
   )
 
   expect_snapshot(
-    out <- arc_geo_categories("POI",
-      x = -3.7242, y = 40.39094,
+    out <- arc_geo_categories(
+      "POI",
+      x = -3.7242,
+      y = 40.39094,
       bbox = c(-200, -89, 200, 89),
       verbose = TRUE
     )
   )
 
   expect_snapshot(
-    out <- arc_geo_categories("POI",
-      x = -3.7242, y = 40.39094,
+    out <- arc_geo_categories(
+      "POI",
+      x = -3.7242,
+      y = 40.39094,
       bbox = c(-200, -89, 200, 89),
       verbose = TRUE
     )
   )
 
   expect_snapshot(
-    out <- arc_geo_categories("POI",
-      x = -3.7242, y = 40.39094,
+    out <- arc_geo_categories(
+      "POI",
+      x = -3.7242,
+      y = 40.39094,
       bbox = c(-100, -95, 100, 95),
       verbose = TRUE
     )
@@ -125,11 +135,11 @@ test_that("Test with all params", {
   skip_if_api_server()
   skip_if_offline()
 
-
-
   expect_snapshot(
-    out <- arc_geo_categories("POI,Address",
-      x = -3.7242, y = 40.39094,
+    out <- arc_geo_categories(
+      "POI,Address",
+      x = -3.7242,
+      y = 40.39094,
       name = "Bar",
       limit = 20,
       lon = "aaaa",
@@ -149,11 +159,13 @@ test_that("Test with all params", {
   expect_true("aaaa" %in% names(out))
   expect_true("LongLabel" %in% names(out))
   expect_false("query" %in% names(out))
-  expect_false(any(grepl("Country", names(out))))
+  expect_false(any(grepl("Country", names(out), fixed = TRUE)))
 
   # Full results
-  out2 <- arc_geo_categories("POI,Bakery",
-    x = -3.7242, y = 40.39094,
+  out2 <- arc_geo_categories(
+    "POI,Bakery",
+    x = -3.7242,
+    y = 40.39094,
     limit = 2,
     lon = "aaaa",
     lat = "bbbb",
@@ -171,7 +183,7 @@ test_that("Test with all params", {
   expect_true("aaaa" %in% names(out2))
   expect_true("LongLabel" %in% names(out2))
   expect_false("query" %in% names(out))
-  expect_true(any(grepl("Country", names(out2))))
+  expect_true(any(grepl("Country", names(out2), fixed = TRUE)))
   expect_gt(ncol(out2), ncol(out))
   # Vectorized
   expect_gt(nrow(out2), 2)
